@@ -46,6 +46,7 @@
 #include "tagmanager.hpp"
 #include "utils.hpp"
 #include "debug.hpp"
+#include "notebooks/notebookmanager.hpp"
 #include "sharp/exception.hpp"
 #include "sharp/fileinfo.hpp"
 #include "sharp/files.hpp"
@@ -136,7 +137,6 @@ namespace gnote {
     , m_height(0)
     , m_x(s_noPosition)
     , m_y(s_noPosition)
-    , m_open_on_startup(false)
   {
   }
 
@@ -278,7 +278,7 @@ namespace gnote {
     , m_save_needed(false)
     , m_is_deleting(false)
     , m_enabled(true)
-    , m_note_window_embeded(false)
+    , m_note_window_embedded(false)
     , m_focus_widget(NULL)
     , m_manager(_manager)
     , m_window(NULL)
@@ -870,11 +870,6 @@ namespace gnote {
             DBG_OUT("loading tag subtree failed");
           }
         }
-        else if(name == "open-on-startup") {
-          // TODO this is a hacked on observation about how Mono convert
-          // a bool from a string.
-          set_is_open_on_startup(xml.read_string() == "True");
-        }
         break;
       default:
         break;
@@ -1013,14 +1008,14 @@ namespace gnote {
         m_window->set_position(m_data.data().x(), m_data.data().y());
       }
 
-      m_window->signal_embeded.connect(sigc::mem_fun(*this, &Note::on_note_window_embeded));
+      m_window->signal_embedded.connect(sigc::mem_fun(*this, &Note::on_note_window_embedded));
     }
     return m_window;
   }
 
-  void Note::on_note_window_embeded()
+  void Note::on_note_window_embedded()
   {
-    if(!m_note_window_embeded) {
+    if(!m_note_window_embedded) {
       // This is here because emiting inside
       // OnRealized causes segfaults.
       m_signal_opened(*this);
@@ -1028,8 +1023,10 @@ namespace gnote {
       // Add any child widgets if any exist now that
       // the window is showing.
       process_child_widget_queue();
-      m_note_window_embeded = true;
+      m_note_window_embedded = true;
     }
+
+    notebooks::NotebookManager::instance().active_notes_notebook()->add_note(shared_from_this());
   }
 
   bool Note::is_special() const
@@ -1076,23 +1073,9 @@ namespace gnote {
       }
     }
     settings->set_string(Preferences::MENU_PINNED_NOTES, new_pinned);
+    notebooks::NotebookManager::instance().signal_note_pin_status_changed(*this, pinned);
   }
 
-  
-  bool Note::is_open_on_startup() const
-  {
-    return data().is_open_on_startup();
-  }
-
-
-  void Note::set_is_open_on_startup(bool value)
-  {
-    if (data().is_open_on_startup() != value) {
-      data().set_is_open_on_startup(value);
-      m_save_needed = true;
-    }
-  }
-  
   void Note::get_tags(std::list<Tag::Ptr> & l) const
   {
     sharp::map_get_values(m_data.data().tags(), l);
@@ -1215,9 +1198,6 @@ namespace gnote {
             DBG_OUT("loading tag subtree failed");
           }
         }
-        else if(name == "open-on-startup") {
-          note->set_is_open_on_startup(xml.read_string() == "True");
-        }
         break;
 
       default:
@@ -1359,10 +1339,6 @@ namespace gnote {
       xml.write_end_element();
     }
 
-    xml.write_start_element("", "open-on-startup", "");
-    xml.write_string(note.is_open_on_startup() ? "True" : "False");
-    xml.write_end_element();
-
     xml.write_end_element(); // Note
     xml.write_end_document();
 
