@@ -162,14 +162,6 @@ public:
       return m_tags;
     }
 
-  bool is_open_on_startup() const
-    {
-      return m_open_on_startup;
-    }
-  void set_is_open_on_startup(bool v)
-    {
-      m_open_on_startup = v;
-    }
   void set_position_extent(int x, int y, int width, int height);
   bool has_position();
   bool has_extent();
@@ -185,7 +177,6 @@ private:
   int               m_selection_bound_pos;
   int               m_width, m_height;
   int               m_x, m_y;
-  bool              m_open_on_startup;
 
   TagMap m_tags;
 };
@@ -340,8 +331,6 @@ public:
     }
   bool is_pinned() const;
   void set_pinned(bool pinned) const;
-  bool is_open_on_startup() const;
-  void set_is_open_on_startup(bool);
   void get_tags(std::list<Tag::Ptr> &) const;
   bool enabled() const
     {
@@ -384,7 +373,7 @@ private:
                     const Ptr & renamed);
   void remove_links(const std::string & old_title,
                     const Ptr & renamed);
-  void on_note_window_embeded();
+  void on_note_window_embedded();
 
   Note(NoteData * data, const std::string & filepath, NoteManager & manager);
 
@@ -405,7 +394,7 @@ private:
   bool                       m_save_needed;
   bool                       m_is_deleting;
   bool                       m_enabled;
-  bool                       m_note_window_embeded;
+  bool                       m_note_window_embedded;
 
   Gtk::Widget               *m_focus_widget;
   NoteManager               &m_manager;
