@@ -34,6 +34,7 @@
 
 #include "libtomboy/tomboyutil.h"
 #include "debug.hpp"
+#include "iconmanager.hpp"
 #include "note.hpp"
 #include "notewindow.hpp"
 #include "notemanager.hpp"
@@ -45,12 +46,25 @@
 #include "search.hpp"
 #include "actionmanager.hpp"
 #include "tagmanager.hpp"
+#include "notebooks/notebookmanager.hpp"
 #include "sharp/exception.hpp"
 #include "sharp/string.hpp"
 
 
 namespace gnote {
 
+  Glib::RefPtr<Gio::Icon> NoteWindow::get_icon_pin_active()
+  {
+    return IconManager::obj().get_icon(IconManager::PIN_ACTIVE, 22);
+  }
+
+  Glib::RefPtr<Gio::Icon> NoteWindow::get_icon_pin_down()
+  {
+    return IconManager::obj().get_icon(IconManager::PIN_DOWN, 22);
+  }
+
+
+
   NoteWindow::NoteWindow(Note & note)
     : Gtk::VBox(false, 2)
     , m_note(note)
@@ -142,29 +156,37 @@ namespace gnote {
     return m_name;
   }
 
-  void NoteWindow::embed(utils::EmbedableWidgetHost *h)
+  void NoteWindow::set_name(const std::string & name)
+  {
+    m_name = name;
+    signal_name_changed(m_name);
+  }
+
+  void NoteWindow::embed(utils::EmbeddableWidgetHost *h)
   {
     //remove from previous host, if any
     if(host()) {
       host()->unembed_widget(*this);
     }
-    utils::EmbedableWidget::embed(h);
+    utils::EmbeddableWidget::embed(h);
   }
 
   void NoteWindow::foreground()
   {
     //addins may add accelarators, so accel group must be there
-    utils::EmbedableWidgetHost *current_host = host();
+    utils::EmbeddableWidgetHost *current_host = host();
     Gtk::Window *parent = dynamic_cast<Gtk::Window*>(current_host);
     if(parent) {
       add_accel_group(*parent);
     }
 
-    utils::EmbedableWidget::foreground();
+    utils::EmbeddableWidget::foreground();
     if(parent) {
       parent->set_default_size(m_width, m_height);
-      if((parent->get_window()->get_state() & Gdk::WINDOW_STATE_MAXIMIZED) == 0 && parent->get_visible()) {
-        parent->get_window()->resize(m_width, m_height);
+      Glib::RefPtr<Gdk::Window> parent_window = parent->get_window();
+      if(parent_window != 0 && (parent_window->get_state() & Gdk::WINDOW_STATE_MAXIMIZED) == 0
+         && parent->get_visible()) {
+        parent_window->resize(m_width, m_height);
       }
       if(m_x >= 0 && m_y >= 0 && !current_host->running()) {
         parent->move(m_x, m_y);
@@ -176,13 +198,14 @@ namespace gnote {
 
   void NoteWindow::background()
   {
-    utils::EmbedableWidget::background();
+    utils::EmbeddableWidget::background();
     Gtk::Window *parent = dynamic_cast<Gtk::Window*>(host());
     if(!parent) {
       return;
     }
     remove_accel_group(*parent);
-    if((parent->get_window()->get_state() & Gdk::WINDOW_STATE_MAXIMIZED) == 0) {
+    if(parent->get_window() != 0
+       && (parent->get_window()->get_state() & Gdk::WINDOW_STATE_MAXIMIZED) == 0) {
       int cur_x, cur_y, cur_width, cur_height;
       parent->get_position(cur_x, cur_y);
       parent->get_size(cur_width, cur_height);
@@ -351,6 +374,20 @@ namespace gnote {
   {
     Gtk::Toolbar *tb = new Gtk::Toolbar();
 
+    m_pin_image = manage(new Gtk::Image);
+    if(m_note.is_pinned()) {
+      m_pin_image->property_gicon() = get_icon_pin_down();
+    }
+    else {
+      m_pin_image->property_gicon() = get_icon_pin_active();
+    }
+
+    m_pin_button = manage(new Gtk::ToolButton(*m_pin_image, _("Pin")));
+    m_pin_button->signal_clicked().connect(sigc::mem_fun(*this, &NoteWindow::on_pin_button_clicked));
+    tb->insert(*m_pin_button, -1);
+    notebooks::NotebookManager::instance().signal_note_pin_status_changed
+      .connect(sigc::mem_fun(*this, &NoteWindow::on_pin_status_changed));
+
     m_link_button = manage(new Gtk::ToolButton(
                              *manage(new Gtk::Image (Gtk::Stock::JUMP_TO, tb->get_icon_size())),
                              _("Link")));
@@ -641,6 +678,24 @@ namespace gnote {
     Glib::RefPtr<NoteBuffer>::cast_static(m_editor->get_buffer())->change_cursor_depth_directional(false);
   }
 
+  void NoteWindow::on_pin_status_changed(const Note & note, bool pinned)
+  {
+    if(&m_note != &note) {
+      return;
+    }
+    if(pinned) {
+      m_pin_image->property_gicon() = get_icon_pin_down();
+    }
+    else {
+      m_pin_image->property_gicon() = get_icon_pin_active();
+    }
+  }
+
+  void NoteWindow::on_pin_button_clicked()
+  {
+    m_note.set_pinned(!m_note.is_pinned());
+  }
+
 
   NoteFindBar::NoteFindBar(Note & note)
     : Gtk::HBox(false, 0)
