@@ -100,18 +100,15 @@ private:
 
 class NoteWindow 
   : public Gtk::VBox
-  , public utils::EmbedableWidget
+  , public utils::EmbeddableWidget
 {
 public:
   NoteWindow(Note &);
   ~NoteWindow();
 
   virtual std::string get_name() const;
-  void set_name(const std::string & name)
-    {
-      m_name = name;
-    }
-  virtual void embed(utils::EmbedableWidgetHost *h);
+  void set_name(const std::string & name);
+  virtual void embed(utils::EmbeddableWidgetHost *h);
   virtual void foreground();
   virtual void background();
 
@@ -154,6 +151,9 @@ public:
       return *m_find_bar;
     }
 private:
+  static Glib::RefPtr<Gio::Icon> get_icon_pin_active();
+  static Glib::RefPtr<Gio::Icon> get_icon_pin_down();
+
   bool on_key_pressed(GdkEventKey*);
   void on_delete_button_clicked();
   void on_selection_mark_set(const Gtk::TextIter&, const Glib::RefPtr<Gtk::TextMark>&);
@@ -179,6 +179,8 @@ private:
   void change_depth_left_handler();
   void add_accel_group(Gtk::Window &);
   void remove_accel_group(Gtk::Window &);
+  void on_pin_status_changed(const Note &, bool);
+  void on_pin_button_clicked();
 
   Note                        & m_note;
   std::string                   m_name;
@@ -188,6 +190,8 @@ private:
   int                           m_y;
   Glib::RefPtr<Gtk::AccelGroup> m_accel_group;
   Gtk::Toolbar                 *m_toolbar;
+  Gtk::Image                   *m_pin_image;
+  Gtk::ToolButton              *m_pin_button;
   Gtk::ToolButton              *m_link_button;
   NoteTextMenu                 *m_text_menu;
   Gtk::Menu                    *m_plugin_menu;
