@@ -40,34 +40,27 @@ typedef utils::ForcedPresentWindow NoteRecentChangesParent;
 
 class NoteRecentChanges
   : public NoteRecentChangesParent
-  , public std::tr1::enable_shared_from_this<NoteRecentChanges>
-  , public utils::EmbedableWidgetHost
+  , public utils::EmbeddableWidgetHost
 {
 public:
-  typedef std::tr1::shared_ptr<NoteRecentChanges> Ptr;
-  typedef std::tr1::weak_ptr<NoteRecentChanges> WeakPtr;
-
-  static Ptr create(NoteManager& m)
-    {
-      return Ptr(new NoteRecentChanges(m));
-    }
-  static Ptr get_owning(Gtk::Widget & widget);
+  static NoteRecentChanges *get_owning(Gtk::Widget & widget);
 
+  NoteRecentChanges(NoteManager& m);
   virtual ~NoteRecentChanges();
   void set_search_text(const std::string & value);
   void present_note(const Note::Ptr & note);
   void new_note();
+  void present_search();
 
-  virtual void embed_widget(utils::EmbedableWidget &);
-  virtual void unembed_widget(utils::EmbedableWidget &);
-  virtual void foreground_embeded(utils::EmbedableWidget &);
-  virtual void background_embeded(utils::EmbedableWidget &);
+  virtual void embed_widget(utils::EmbeddableWidget &);
+  virtual void unembed_widget(utils::EmbeddableWidget &);
+  virtual void foreground_embedded(utils::EmbeddableWidget &);
+  virtual void background_embedded(utils::EmbeddableWidget &);
   virtual bool running()
     {
       return m_mapped;
     }
 protected:
-  NoteRecentChanges(NoteManager& m);
   virtual void on_show();
   virtual bool on_map_event(GdkEventAny *evt);
 private:
@@ -77,19 +70,19 @@ private:
   void on_close_window();
   bool on_delete(GdkEventAny *);
   bool on_key_pressed(GdkEventKey *);
-  bool is_foreground(utils::EmbedableWidget &);
-  void on_embeded_widget_menu_item_toggled(Gtk::RadioMenuItem *, utils::EmbedableWidget *);
-  void on_menu_show();
-  utils::EmbedableWidget *currently_embeded();
+  bool is_foreground(utils::EmbeddableWidget &);
+  utils::EmbeddableWidget *currently_embedded();
+  Gtk::Toolbar *make_toolbar();
+  void on_embedded_name_changed(const std::string & name);
 
   NoteManager        &m_note_manager;
   SearchNotesWidget   m_search_notes_widget;
   Gtk::VBox           m_content_vbox;
   Gtk::VBox           m_embed_box;
-  std::list<utils::EmbedableWidget*> m_embeded_widgets;
-  Gtk::Menu          *m_menu;
-  Gtk::RadioMenuItem::Group m_tool_menu_group;
+  Gtk::ToolButton    *m_all_notes_button;
+  std::list<utils::EmbeddableWidget*> m_embedded_widgets;
   bool                m_mapped;
+  sigc::connection    m_current_embedded_name_slot;
 };
 
 
