@@ -41,7 +41,7 @@ namespace gnote {
 
 class SearchNotesWidget
   : public Gtk::VBox
-  , public utils::EmbedableWidget
+  , public utils::EmbeddableWidget
 {
 public:
   SearchNotesWidget(NoteManager & m);
@@ -78,7 +78,7 @@ private:
   void on_notebook_selection_changed();
   bool on_notebooks_tree_button_pressed(GdkEventButton *);
   bool on_notebooks_key_pressed(GdkEventKey *);
-  notebooks::Notebook::Ptr get_selected_notebook();
+  notebooks::Notebook::Ptr get_selected_notebook() const;
   void update_results();
   void popup_context_menu_at_location(Gtk::Menu *, int, int);
   Note::List get_selected_notes();
@@ -117,6 +117,7 @@ private:
   Gtk::Window *get_owning_window();
   void on_note_added_to_notebook(const Note & note, const notebooks::Notebook::Ptr & notebook);
   void on_note_removed_from_notebook(const Note & note, const notebooks::Notebook::Ptr & notebook);
+  void on_note_pin_status_changed(const Note &, bool);
   Gtk::Menu *get_note_list_context_menu();
   Gtk::Menu *get_notebook_list_context_menu();
   void on_open_notebook_template_note();
@@ -177,14 +178,9 @@ private:
   Gtk::Menu *m_notebook_list_context_menu;
   bool m_initial_position_restored;
 
-  static void _init_static();
+  static Glib::RefPtr<Gdk::Pixbuf> get_note_icon();
 
   static std::list<std::string> s_previous_searches;
-  static bool s_static_inited;
-  static Glib::RefPtr<Gdk::Pixbuf> s_note_icon;
-  static Glib::RefPtr<Gdk::Pixbuf> s_all_notes_icon;
-  static Glib::RefPtr<Gdk::Pixbuf> s_unfiled_notes_icon;
-  static Glib::RefPtr<Gdk::Pixbuf> s_notebook_icon;
 };
 
 }
